@@ -71,10 +71,11 @@ def categorical_focal_loss(alpha=0.25, gamma=2.):
         y_pred = K.clip(y_pred,epsilon,1. - epsilon)
 
         # Calculate Cross Entropy
+        y_true = K.cast(y_true,K.floatx())
         cross_entropy = -y_true * K.log(y_pred)
 
         # Calculate Focal Loss
-        loss = alpha * K.pow(1 - y_pred, gamma) * cross_entropy
+        loss =  K.pow(1 - y_pred, gamma) * cross_entropy
 
         # Compute mean loss in mini_batch
         return K.mean(K.sum(loss,axis=-1))
@@ -104,3 +105,52 @@ def loss_with_gradient_penalty(model,loss_func,epsilon=1):
         gp = tf.math.reduce_sum(tf.gradients(loss, [embeddings])[0].values**2)
         return loss + 0.5 * epsilon * gp
     return loss_with_gradient_penalty_2
+
+
+def multi_category_focal_loss2(gamma=2., alpha=1):
+    """
+    focal loss for multi category of multi label problem
+    适用于多分类或多标签问题的focal loss
+    alpha控制真值y_true为1/0时的权重
+        1的权重为alpha, 0的权重为1-alpha
+    当你的模型欠拟合，学习存在困难时，可以尝试适用本函数作为loss
+    当模型过于激进(无论何时总是倾向于预测出1),尝试将alpha调小
+    当模型过于惰性(无论何时总是倾向于预测出0,或是某一个固定的常数,说明没有学到有效特征)
+        尝试将alpha调大,鼓励模型进行预测出1。
+    Usage:
+     model.compile(loss=[multi_category_focal_loss2(alpha=0.25, gamma=2)], metrics=["accuracy"], optimizer=adam)
+    """
+    epsilon = 1.e-7
+    gamma = float(gamma)
+    alpha = tf.constant(alpha, dtype=tf.float32)
+
+    def multi_category_focal_loss2_fixed(y_true, y_pred):
+        y_true = tf.cast(y_true, tf.float32)
+        y_pred = tf.clip_by_value(y_pred, epsilon, 1. - epsilon)
+
+        alpha_t = y_true * alpha + (tf.ones_like(y_true) - y_true) * (1 - alpha)
+        y_t = tf.multiply(y_true, y_pred) + tf.multiply(1 - y_true, 1 - y_pred)
+        ce = -K.log(y_t)
+        weight = tf.pow(tf.subtract(1., y_t), gamma)
+        fl = tf.multiply(tf.multiply(weight, ce), alpha_t)
+        loss = tf.reduce_mean(fl)
+        return loss
+
+    return multi_category_focal_loss2_fixed
+
+
+def multi_category_focal_loss2_fixed(y_true, y_pred):
+    epsilon = 1.e-7
+    gamma=2.
+    alpha = tf.constant(0.5, dtype=tf.float32)
+
+    y_true = tf.cast(y_true, tf.float32)
+    y_pred = tf.clip_by_value(y_pred, epsilon, 1. - epsilon)
+
+    alpha_t = y_true*alpha + (tf.ones_like(y_true)-y_true)*(1-alpha)
+    y_t = tf.multiply(y_true, y_pred) + tf.multiply(1-y_true, 1-y_pred)
+    ce = -K.log(y_t)
+    weight = tf.pow(tf.subtract(1., y_t), gamma)
+    fl = tf.multiply(tf.multiply(weight, ce), alpha_t)
+    loss = tf.reduce_mean(fl)
+    return loss
