@@ -16,7 +16,7 @@ from nlp_tools.embeddings import ABCEmbedding,TransformerEmbedding,BertEmbedding
 from nlp_tools.optimizer import MultiOptimizer
 from tensorflow.keras.optimizers import Adam
 
-from transformers.optimization_tf import AdamWeightDecay
+#from transformers.optimization_tf import AdamWeightDecay
 from nlp_tools.loss.r_drop_loss import RDropLoss
 
 class ABCClassificationModel(ABCTaskModel,ABC):
