@@ -37,4 +37,20 @@ def unison_shuffled_copies(a: List[T],
     a, b = zip(*c)
     if data_type == np.ndarray:
         return np.array(a), np.array(b)
-    return list(a), list(b)
\ No newline at end of file
+    return list(a), list(b)
+
+
+def load_vocab(dict_path, encoding='utf-8', startswith=None):
+    """词典文件中读取词典
+    """
+    token_list = []
+    with open(dict_path, encoding=encoding) as reader:
+        for line in reader:
+            token = line.strip()
+            if token:
+                token_list.append(token)
+    if startswith:
+        token_list = startswith + list(set(token_list))
+    token_dict = {key:index for index,key in enumerate(token_list)}
+
+    return token_dict
\ No newline at end of file
